;; Generated package description from easy-kill.el  -*- no-byte-compile: t -*-
(define-package "easy-kill" "0.9.3.0.20140422.153731" "kill & mark things easily" '((emacs "24") (cl-lib "0.5")) :keywords '("killing" "convenience") :authors '(("Leo Liu" . "sdl.web@gmail.com")) :maintainer '("Leo Liu" . "sdl.web@gmail.com") :url "https://github.com/leoliu/easy-kill")
